# Vantage client

::: vantage_sdk.client
    options:
        show_root_heading: true
        show_source: false
        docstring_style: numpy
        docstring_section_style: table
        merge_init_into_class: true
        show_docstring_attributes: true
        show_docstring_classes: true
        show_docstring_examples: true

::: vantage_sdk.model.collection
    options:
        show_root_heading: true
        show_source: false
        docstring_style: numpy
        docstring_section_style: table
        merge_init_into_class: true
        show_docstring_attributes: true
        show_docstring_parameters: false
        show_docstring_classes: true
        show_docstring_examples: true
        show_submodules: true

::: vantage_sdk.model.keys
    options:
        show_root_heading: true
        show_source: false
        docstring_style: numpy
        docstring_section_style: table
        merge_init_into_class: true
        show_docstring_attributes: true
        show_docstring_parameters: false
        show_docstring_classes: true
        show_docstring_examples: true
        show_submodules: true

::: vantage_sdk.core.management.management
    options:
        show_root_heading: true
        show_source: false
        docstring_style: numpy
        docstring_section_style: table
        merge_init_into_class: true
        show_docstring_attributes: true
        show_docstring_classes: true
        show_docstring_examples: true
        show_submodules: true
        show_if_no_docstring: false



::: vantage_sdk.core.search.search
    options:
        show_root_heading: true
        show_source: false
        docstring_style: numpy
        docstring_section_style: table
        merge_init_into_class: true
        show_docstring_attributes: true
        show_docstring_classes: true
        show_docstring_examples: true
        show_submodules: true
        show_if_no_docstring: false

# Exceptions

::: vantage_sdk.core.exceptions
    options:
        show_root_heading: false
        show_source: false
        docstring_style: numpy
        docstring_section_style: table
        merge_init_into_class: true
        show_docstring_attributes: true
        show_docstring_classes: true
        show_docstring_examples: true
        show_submodules: false
        show_if_no_docstring: false

# Models generated from OpenAPI specification

Part of the source code has been generated using OpenAPI specification of VantageDiscovery API. Users of SDK will most likely use some of these modules, and thus we are listing them here for reference.

::: vantage_sdk.core.http.models
    options:
        show_root_heading: false
        show_source: false
        docstring_style: numpy
        docstring_section_style: table
        merge_init_into_class: true
        show_docstring_attributes: true
        show_docstring_classes: true
        show_docstring_examples: true
        show_submodules: true
        show_if_no_docstring: false
